# Generated by roxygen2: do not edit by hand

S3method(print,dt2_theme)
export(dt2)
export(dt2_bind_server)
export(dt2_buttons)
export(dt2_check_updates)
export(dt2_col_button)
export(dt2_col_checkbox)
export(dt2_col_template)
export(dt2_cols_align)
export(dt2_cols_escape)
export(dt2_cols_hide)
export(dt2_cols_html)
export(dt2_cols_render_js)
export(dt2_cols_render_orthogonal)
export(dt2_cols_width)
export(dt2_draw)
export(dt2_extensions)
export(dt2_format_datetime)
export(dt2_format_number)
export(dt2_format_number_abbrev)
export(dt2_format_time_format)
export(dt2_format_time_relative)
export(dt2_language)
export(dt2_length_menu)
export(dt2_order)
export(dt2_output)
export(dt2_proxy)
export(dt2_proxy_order)
export(dt2_proxy_page)
export(dt2_proxy_search)
export(dt2_register_renderer)
export(dt2_replace_data)
export(dt2_search_global)
export(dt2_select_rows)
export(dt2_ssp_handler)
export(dt2_state)
export(dt2_theme)
export(dt2_update_libs)
export(dt2_use_buttons)
export(dt2_use_renderer)
export(observe_dt2_events)
export(render_dt2)
importFrom(htmltools,htmlDependency)
