% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_inputs.R
\name{dt2_col_checkbox}
\alias{dt2_col_checkbox}
\title{Checkbox input per row}
\usage{
dt2_col_checkbox(
  options = list(),
  col,
  input_id_prefix = "row_chk_",
  value_col = NULL
)
}
\arguments{
\item{options}{Options list.}

\item{col}{Target column (name or 1-based index).}

\item{input_id_prefix}{Prefix for element ids (e.g., "row_chk_").}

\item{value_col}{Optional boolean column to define initial state.}
}
\value{
Updated \code{options}.
}
\description{
Checkbox input per row
}
