% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_extensions.R
\name{.dt2_resolve_extensions}
\alias{.dt2_resolve_extensions}
\title{Resolve extension names with dependency ordering}
\usage{
.dt2_resolve_extensions(extensions)
}
\arguments{
\item{extensions}{character vector of extension names}
}
\value{
ordered character vector (dependencies first)
}
\description{
Resolve extension names with dependency ordering
}
\keyword{internal}
