% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_check_updates.R
\name{.version_gt}
\alias{.version_gt}
\title{Compare two version strings (a > b?)}
\usage{
.version_gt(a, b)
}
\description{
Compare two version strings (a > b?)
}
\keyword{internal}
