% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_inputs.R
\name{dt2_col_button}
\alias{dt2_col_button}
\title{Action button per row}
\usage{
dt2_col_button(
  options = list(),
  col,
  label = "Action",
  input_id_prefix = "row_btn_"
)
}
\arguments{
\item{options}{Options list.}

\item{col}{Target column (name or 1-based index).}

\item{label}{Button label.}

\item{input_id_prefix}{Prefix for element ids (e.g., "row_btn_").}
}
\value{
Updated \code{options}.
}
\description{
Action button per row
}
