% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_server_processing.R
\name{.dt2_payload}
\alias{.dt2_payload}
\title{Internal: build DataTables JSON payload}
\usage{
.dt2_payload(draw, total, filtered, data_rows)
}
\description{
Internal: build DataTables JSON payload
}
\keyword{internal}
