% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_formats.R
\name{dt2_cols_render_js}
\alias{dt2_cols_render_js}
\title{Attach a raw JS render function to columns}
\usage{
dt2_cols_render_js(options = list(), col_specs, js_render)
}
\arguments{
\item{options}{List returned, with \code{columnDefs} appended.}

\item{col_specs}{Column names or indices.}

\item{js_render}{A \code{htmlwidgets::JS()} function of signature
\code{function(data, type, row, meta) { ... }}.}
}
\value{
Modified \code{options}.
}
\description{
Provide a custom JS renderer for one or more columns. Use this when
you need fine control over \code{columns.render}, including returning
different outputs based on \code{type} (display/sort/filter/type).
}
\seealso{
\url{https://datatables.net/reference/option/columns.render}
}
