% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_extensions.R
\name{.dt2_detect_extensions}
\alias{.dt2_detect_extensions}
\title{Auto-detect extensions from options}
\usage{
.dt2_detect_extensions(options)
}
\arguments{
\item{options}{DataTables options list}
}
\value{
character vector of detected extension names
}
\description{
Scans the options list for keys that imply certain extensions.
For example, \code{buttons} implies Buttons, \code{select} implies Select, etc.
}
\keyword{internal}
