% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_formats.R
\name{dt2_cols_render_orthogonal}
\alias{dt2_cols_render_orthogonal}
\title{Orthogonal render (display/sort/filter/type) per column}
\usage{
dt2_cols_render_orthogonal(
  options = list(),
  col_specs,
  display = NULL,
  sort = NULL,
  filter = NULL,
  type = NULL
)
}
\arguments{
\item{options}{Options list to modify.}

\item{col_specs}{Column names or indices.}

\item{display}{Optional JS renderer for UI display.}

\item{sort}{Optional JS renderer used for ordering.}

\item{filter}{Optional JS renderer used for searching.}

\item{type}{Optional JS renderer used for type detection.}
}
\value{
Modified \code{options}.
}
\description{
Supply different renderers for each orthogonal data request. Pass an
object with keys \code{display}, \code{sort}, \code{filter}, \code{type}
(all optional). Each value must be a JS function.
}
\examples{
opts <- list(columns = names(iris))
opts <- dt2_cols_render_orthogonal(
  opts, "Sepal.Length",
  display = htmlwidgets::JS("function(d,t,row,meta){ return d + ' cm'; }"),
  sort    = htmlwidgets::JS("function(d,t,row,meta){ return parseFloat(d); }")
)
}
