% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dt2_shiny.R
\name{render_dt2}
\alias{render_dt2}
\title{Shiny render function for DT2}
\usage{
render_dt2(expr, env = parent.frame(), quoted = FALSE)
}
\arguments{
\item{expr}{Expression returning a \code{\link[=dt2]{dt2()}} widget.}

\item{env, quoted}{Standard \code{shinyRenderWidget} arguments.}
}
\value{
A Shiny render function (closure produced by
\code{\link[htmlwidgets:shinyRenderWidget]{htmlwidgets::shinyRenderWidget()}}) that emits a DT2 widget.
}
\description{
Render a DT2 table in a Shiny server function.
}
